<?php
/*
 * Plugin Name: EzTAP Profile Button
 * Description: Adds a beautiful EzTAP Profile Button on the WordPress frontend.
 * Author:      TweekersNut Network
 * Author URI:  https://tweekersnut.com
 * Version:     1.0.0
 * License:     GPLv2
 * Text Domain: ez
 * Domain Path: /languages/
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Define constants
define('EZ_VERSION', '1.0.0');
define('EZ_NAME', plugin_basename(__FILE__));
define('EZ_DIR', plugin_dir_path(__FILE__));
define('EZ_URI', plugin_dir_url(__FILE__));
define('EZ_INC', trailingslashit(EZ_DIR . 'includes'));

// Check main class exists
if (!class_exists('EZ_Main')) {

    // Include whatsapp chat button frontend
    include EZ_INC . 'frontend.php';

    // Define main class
    class EZ_Main {

        public function __construct() {
            // Add settings page
            add_action('admin_menu', array($this, 'EZ_settings_page'));

            // Register settings
            add_action('admin_init', array($this, 'EZ_register_settings'));

            // Add custom meta box
            add_action('add_meta_boxes', array($this,'EZ_add_custom_meta_box'));

            // Add save custom meta box data
            add_action('save_post', array($this, 'EZ_save_post_data'));

            // Add settings link
            add_filter('plugin_action_links_' . EZ_NAME, array($this, 'EZ_add_settings_link'));

            // Loads translated strings
            load_plugin_textdomain('ez', false, dirname(EZ_NAME) . '/languages');
        }

        // Add setting page to options submenu
        function EZ_settings_page() {
            add_submenu_page(
                'options-general.php',
                esc_html__('EzTAP Profile Button', 'ez'),
                esc_html__('EzTAP Profile Button', 'ez'),
                'manage_options',
                'eztap-profile-button',
                array($this, 'EZ_settings_page_callback')
            );
        }

        // Register settings
        function EZ_register_settings() {
			$EZ_settings_args = array (
				'sanitize_callback' => 'sanitize_text_field'
			);
            $EZ_whatsapp_options = array(
                'EZ_profile_link',
            );
            $EZ_button_options = array(
                'EZ_button_status',
                'EZ_button_text',
                'EZ_button_target',
                'EZ_button_position',
                'EZ_button_z_index',
                'EZ_desktop_link_type',
                'EZ_desktop_bottom_margin',
                'EZ_tablet_bottom_margin',
                'EZ_mobile_bottom_margin'
            );
            foreach ($EZ_whatsapp_options as $option) {
                register_setting('scb-eztap-profile-settings', $option, $EZ_settings_args);
            }
            foreach ($EZ_button_options as $option) {
                register_setting('scb-button-settings', $option, $EZ_settings_args);
            }
            // Initialize options
            add_option('EZ_button_status', '1');
            add_option('EZ_button_text', esc_html__('Visit profile?', 'ez'));
            add_option('EZ_button_target', '_blank');
            add_option('EZ_button_position', 'right');
            add_option('EZ_desktop_link_type', 'web');
            add_option('EZ_desktop_bottom_margin', '20');
            add_option('EZ_tablet_bottom_margin', '20');
            add_option('EZ_mobile_bottom_margin', '20');
        }

        // Settings page callback
        function EZ_settings_page_callback() {
            // Check access
            if (!current_user_can("manage_options") && !is_admin()) {
                return;
            }
            // Include settings page
            include EZ_INC . 'settings-page.php';
        }

        // Add custom meta box
        function EZ_add_custom_meta_box() {
            $screens = array(
                'post',
                'page',
            );
            foreach ($screens as $screen) {
                add_meta_box(
                    'EZ_custom_meta_box',
                    esc_html__('EzTAP Profile Button Settings', 'ez'),
                    array($this, 'EZ_custom_meta_box_callback'),
                    $screen,
                    'normal',
                    'default',
                );
            }
        }

        // Custom meta box html
        function EZ_custom_meta_box_callback($post) {
            // Check access
            if (!current_user_can("manage_options") && !is_admin()) {
                return;
            }
            // Include meta box html
            include EZ_INC . 'meta-box.php';
        }

        // Save custom meta box data
        function EZ_save_post_data($post_id){
            // Check plugin nonce is set
            if (!isset($_POST['EZ_settings_meta_box_nonce'])) {
                return $post_id;
            }

            // Verify that the nonce is valid
            $nonce = sanitize_text_field($_POST['EZ_settings_meta_box_nonce']);
            if (!wp_verify_nonce($nonce, 'EZ_settings_meta_box')) {
                return $post_id;
            }

            // Check auto save form
            if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
                return $post_id;
            }

            // Check the user permissions
            if ('page' == $_POST['post_type']) {
                if (!current_user_can('edit_page', $post_id)) {
                    return $post_id;
                }
            } else {
                if (!current_user_can('edit_post', $post_id)) {
                    return $post_id;
                }
            }

            // Sanitize the user input and save post meta
            $button_hide_status = sanitize_text_field($_POST['EZ_button_hide_status']);
            if (!empty($button_hide_status)) {
                update_post_meta($post_id, '_EZ_button_hide_status', $button_hide_status);
            } else {
                delete_post_meta($post_id, '_EZ_button_hide_status');
            }
        }

        // Add settings link
        function EZ_add_settings_link($links) {
            $links[] = sprintf('<a href="%1$s">%2$s</a>', admin_url('options-general.php?page=eztap-profile-button'), esc_html__('Settings', 'ez'));
            $links[] = sprintf('<a href="https://tweekersnut.com">%1$s</a>', esc_html__('Website', 'ez'));
            return $links;
        }

    }

    new EZ_Main();
}
